import { EventEmitter } from "../../stencil-public-runtime";
import { ModalTransitionStatusType } from "./modal-status";
export declare class Modal {
  domNode: HTMLUxModalElement;
  /** Set the name of the modal  */
  name: string;
  /** Set the priority of the modal as integer between 1 and 10 - lower numbers have a higher importance */
  priority: number;
  /** The label of the close button */
  closeButtonText: string;
  /** Disables the close button in the top corner */
  noCloseButton: boolean;
  /** If present, uxModalClose event is emitted when escape key is pressed **/
  closeOnEscKey: boolean;
  /** If present, uxModalClose event is emitted when the backdrop is clicked **/
  closeOnBackdropClick: boolean;
  /** reloads the page when the modal is closed */
  reloadOnClose: boolean;
  /** At which vertical position should the maodal be docked **/
  stickyPosition: "center" | "bottom" | "top";
  /** Boolean to indicate if or not the modal is currently opened */
  opened: boolean;
  /** The modal transition status */
  status: ModalTransitionStatusType;
  /** List of multiple opened Modals that should be displayed via the ModalManager */
  multipleModals: string[] | null;
  /** List of multiple opened Modals that should be displayed via the ModalManager */
  multipleModalsCurrent: string | null;
  /** Emitted when the modal is closed  */
  modalClosed: EventEmitter<string>;
  /** Emitted when the modal is opened  */
  modalOpened: EventEmitter<string>;
  private transitionTimeout;
  /** Triggers modal closing */
  triggerClose(): Promise<void>;
  /** Triggers modal opening */
  triggerOpen(): Promise<void>;
  onOtherClosedModal(e: CustomEvent): void;
  onOtherOpenedModal(e: CustomEvent): void;
  /** Listen for opened state  */
  setModalStatus(): void;
  private initMultipleModals;
  private setMultipleModalsCurrent;
  private getOpenMultipleModals;
  private cleanupMultipleModals;
  private sortMultipleModals;
  private showModal;
  /** Listen for escape key  */
  handleKeyDown(event: KeyboardEvent): void;
  private triggerElementClickHandler;
  componentWillLoad(): void;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  render(): any;
}
